==> config_entity_cloner-1.0.0-rc1.tar.gz: config_entity_cloner/src/Generators/ConfigEntityClonerProcessor/ConfigEntityClonerProcessorPluginGenerator.php <==
<?php

namespace Drupal\config_entity_cloner\Generators\ConfigEntityClonerProcessor;

use Drupal\Core\Extension\ModuleHandlerInterface;
use DrupalCodeGenerator\Command\BaseGenerator;
use DrupalCodeGenerator\Utils;
use Symfony\Component\Console\Question\Question;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class ConfigEntityClonerProcessorPluginGenerator.
 *
 * @package Drupal\config_entity_cloner\Generators
 */
class ConfigEntityClonerProcessorPluginGenerator extends BaseGenerator {

  /**
   * The command name.
   *
   * @var string
   */
  protected $name = 'config-entity-cloner-processor-plugin';

  /**
   * The description.
   *
   * @var string
   */
  protected $description = 'Generates a ConfigEntityClonerProcessor plugin.';

  /**
   * The alias.
   *
   * @var string
   */
  protected $alias = 'config-entity-cloner-processor';

  /**
   * The template dir path.
   *
   * @var string
   */
  protected $templatePath = __DIR__;

  /**
   * Module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandler
   */
  protected $moduleHandler;

  /**
   * ConfigEntityClonerProcessorPluginGenerator constructor.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   * @param string $name
   *   Then name.
   */
  public function __construct(ModuleHandlerInterface $moduleHandler = NULL, $name = NULL) {
    parent::__construct($name);
    $this->moduleHandler = $moduleHandler;
  }

  /**
   * {@inheritdoc}
   */
  protected function interact(InputInterface $input, OutputInterface $output) {
    $questions = [];
    $questions['machine_name'] = new Question('Module machine name');
    $questions['machine_name']->setValidator([
      Utils::class,
      'validateMachineName',
    ]);

    // Plugin name.
    $questions['plugin_name'] = new Question('Plugin Name');
    $questions['plugin_name']->setValidator([Utils::class, 'validateRequired']);

    // Plugin id.
    $plugin_id = function ($vars) {
      return Utils::camel2machine($vars['plugin_name']);
    };
    $questions['plugin_id'] = new Question('Plugin Id', $plugin_id);

    // Plugin weight.
    $questions['plugin_weight'] = new Question('Plugin weight', 30);

    $this->collectVars($input, $output, $questions);

    // Generateplugin.
    $this->generatePlugin();
  }

  /**
   * Generate plugin.
   */
  protected function generatePlugin() {
    $this->vars['plugin_class'] = Utils::camelize($this->vars['plugin_id']);

    // Création du plugin.
    $this->addFile()
      ->path('src/Plugin/config_entity_cloner/ConfigEntityClonerProcessor/' . $this->vars['plugin_class'] . 'ConfigEntityClonerProcessor.php')
      ->template('templates/plugin.twig');
  }

}

==> config_entity_cloner-1.0.3-rc2.tar.gz: config_entity_cloner/src/Generators/ConfigEntityClonerProcessor/ConfigEntityClonerProcessorPluginGenerator.php <==
<?php

namespace Drupal\config_entity_cloner\Generators\ConfigEntityClonerProcessor;

use Drupal\Core\Extension\ModuleHandlerInterface;
use DrupalCodeGenerator\Command\BaseGenerator;
use DrupalCodeGenerator\Utils;
use Symfony\Component\Console\Question\Question;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class ConfigEntityClonerProcessorPluginGenerator.
 *
 * @package Drupal\config_entity_cloner\Generators
 */
class ConfigEntityClonerProcessorPluginGenerator extends BaseGenerator {

  /**
   * The command name.
   *
   * @var string
   */
  protected $name = 'config-entity-cloner-processor-plugin';

  /**
   * The description.
   *
   * @var string
   */
  protected $description = 'Generates a ConfigEntityClonerProcessor plugin.';

  /**
   * The alias.
   *
   * @var string
   */
  protected $alias = 'config-entity-cloner-processor';

  /**
   * The template dir path.
   *
   * @var string
   */
  protected $templatePath = __DIR__;

  /**
   * Module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandler
   */
  protected $moduleHandler;

  /**
   * ConfigEntityClonerProcessorPluginGenerator constructor.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   * @param string $name
   *   Then name.
   */
  public function __construct(ModuleHandlerInterface $moduleHandler = NULL, $name = NULL) {
    parent::__construct($name);
    $this->moduleHandler = $moduleHandler;
  }

  /**
   * {@inheritdoc}
   */
  protected function interact(InputInterface $input, OutputInterface $output) {
    $questions = [];
    $questions['machine_name'] = new Question('Module machine name');
    $questions['machine_name']->setValidator([
      Utils::class,
      'validateMachineName',
    ]);

    // Plugin name.
    $questions['plugin_name'] = new Question('Plugin Name');
    $questions['plugin_name']->setValidator([Utils::class, 'validateRequired']);

    // Plugin id.
    $plugin_id = function ($vars) {
      return Utils::camel2machine($vars['plugin_name']);
    };
    $questions['plugin_id'] = new Question('Entity type id', $plugin_id);

    // Plugin weight.
    $questions['plugin_weight'] = new Question('Plugin weight', 30);

    $this->collectVars($input, $output, $questions);

    // Init variables variantes.
    $this->vars['plugin_id'] = Utils::human2machine($this->vars['plugin_id']);
    $this->vars['plugin_class'] = Utils::camelize($this->vars['plugin_id']);

    // Generateplugin.
    $this->generatePlugin();
  }

  /**
   * Generate plugin.
   */
  protected function generatePlugin() {
    // Création du plugin.
    $this->addFile()
      ->path('src/Plugin/config_entity_cloner/ConfigEntityClonerProcessor/' . $this->vars['plugin_class'] . 'ConfigEntityClonerProcessor.php')
      ->template('templates/plugin.twig');
  }

}
